.. RestRegistry documentation master file, created by
   sphinx-quickstart on Wed Aug 20 13:33:02 2014.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

UriRegistry
===========

This project aims to provide a central location for keeping track of different
resources through their URI's. It has been designed to answer one simple
question: in which applications is a certain resource (ie. a URI) being used?

.. toctree::
   :maxdepth: 2

   intro
   architecture
   service
   development
   api
   changes


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

